@@ -50,6 +50,8 @@ def build_index(
     nb_cores: Optional[int] = None,
     make_direct_map: bool = False,
     should_be_memory_mappable: bool = False,
+    distributed: Optional[str] = None,
+    temporary_indices_folder: str = "hdfs://root/tmp/distributed_autofaiss_indices",
 ) -> Tuple[Optional[Any], Optional[Dict[str, Union[str, float, int]]]]:
     """
     Reads embeddings and creates a quantized index from them.
@@ -104,6 +106,12 @@ def build_index(
     make_direct_map: bool
         Create a direct map allowing reconstruction of embeddings. This is only needed for IVF indices.
         Note that might increase the RAM usage (approximately 8GB for 1 billion embeddings)
+    distributed: Optional[str]
+        If "pyspark", create the indices using pyspark.
+        Only "parquet" file format is supported.
+    temporary_indices_folder: str
+        Folder to save the temporary small indices that are generated by each spark executor.
+        Only used when distributed = "pyspark".
     """
 
     current_bytes = cast_memory_to_bytes(current_memory_available)
@@ -178,7 +186,7 @@ def build_index(
         if id_columns is not None:
             print(f"Id columns provided {id_columns} - will be reading the corresponding columns")
             if ids_path is not None:
-                print("\tWill be writing the Ids DataFrame in parquet format to {ids_path}")
+                print(f"\tWill be writing the Ids DataFrame in parquet format to {ids_path}")
                 fs, _ = fsspec.core.url_to_fs(ids_path)
                 fs.mkdirs(ids_path, exist_ok=True)
             else:
@@ -205,6 +213,8 @@ def build_index(
                 id_columns=id_columns,
                 embedding_ids_df_handler=write_ids_df_to_parquet if ids_path and id_columns else None,
                 make_direct_map=make_direct_map,
+                distributed=distributed,
+                temporary_indices_folder=temporary_indices_folder,
             )
 
         if index_param is None:
